@@ -51,11 +51,6 @@ test_that("Numbers are tokenized correctly", {
 
 })
 
-test_that("The tokenizer accepts UTF-8 symbols", {
-  expect_true(nrow(tokenize_string("å√∂")) == 1)
-  expect_true(nrow(tokenize_string("¡™£¢∞§¶•ªº≠åß∂ƒ©˙∆˚¬…æΩ≈ç√∫˜µ≤≥÷")) == 1)
-})
-
 test_that("The tokenizer works correctly", {
 
   # TODO: Should newlines be absorbed as part of the comment string?
